@@ -16,15 +16,15 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -33,12 +33,14 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
+
 from google.cloud.tpu_v1.services.tpu import pagers
 from google.cloud.tpu_v1.types import cloud_tpu
-from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import TpuTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import TpuGrpcAsyncIOTransport
+
 from .client import TpuClient
+from .transports.base import DEFAULT_CLIENT_INFO, TpuTransport
+from .transports.grpc_asyncio import TpuGrpcAsyncIOTransport
 
 
 class TpuAsyncClient:
@@ -218,9 +220,9 @@ class TpuAsyncClient:
 
             from google.cloud import tpu_v1
 
-            def sample_list_nodes():
+            async def sample_list_nodes():
                 # Create a client
-                client = tpu_v1.TpuClient()
+                client = tpu_v1.TpuAsyncClient()
 
                 # Initialize request argument(s)
                 request = tpu_v1.ListNodesRequest(
@@ -231,7 +233,7 @@ class TpuAsyncClient:
                 page_result = client.list_nodes(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -290,12 +292,20 @@ class TpuAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListNodesAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -316,9 +326,9 @@ class TpuAsyncClient:
 
             from google.cloud import tpu_v1
 
-            def sample_get_node():
+            async def sample_get_node():
                 # Create a client
-                client = tpu_v1.TpuClient()
+                client = tpu_v1.TpuAsyncClient()
 
                 # Initialize request argument(s)
                 request = tpu_v1.GetNodeRequest(
@@ -326,7 +336,7 @@ class TpuAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_node(request=request)
+                response = await client.get_node(request=request)
 
                 # Handle the response
                 print(response)
@@ -382,7 +392,12 @@ class TpuAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -404,9 +419,9 @@ class TpuAsyncClient:
 
             from google.cloud import tpu_v1
 
-            def sample_create_node():
+            async def sample_create_node():
                 # Create a client
-                client = tpu_v1.TpuClient()
+                client = tpu_v1.TpuAsyncClient()
 
                 # Initialize request argument(s)
                 node = tpu_v1.Node()
@@ -423,7 +438,7 @@ class TpuAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -497,7 +512,12 @@ class TpuAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -525,9 +545,9 @@ class TpuAsyncClient:
 
             from google.cloud import tpu_v1
 
-            def sample_delete_node():
+            async def sample_delete_node():
                 # Create a client
-                client = tpu_v1.TpuClient()
+                client = tpu_v1.TpuAsyncClient()
 
                 # Initialize request argument(s)
                 request = tpu_v1.DeleteNodeRequest(
@@ -539,7 +559,7 @@ class TpuAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -599,7 +619,12 @@ class TpuAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -626,9 +651,9 @@ class TpuAsyncClient:
 
             from google.cloud import tpu_v1
 
-            def sample_reimage_node():
+            async def sample_reimage_node():
                 # Create a client
-                client = tpu_v1.TpuClient()
+                client = tpu_v1.TpuAsyncClient()
 
                 # Initialize request argument(s)
                 request = tpu_v1.ReimageNodeRequest(
@@ -639,7 +664,7 @@ class TpuAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -680,7 +705,12 @@ class TpuAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -707,9 +737,9 @@ class TpuAsyncClient:
 
             from google.cloud import tpu_v1
 
-            def sample_stop_node():
+            async def sample_stop_node():
                 # Create a client
-                client = tpu_v1.TpuClient()
+                client = tpu_v1.TpuAsyncClient()
 
                 # Initialize request argument(s)
                 request = tpu_v1.StopNodeRequest(
@@ -720,7 +750,7 @@ class TpuAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -761,7 +791,12 @@ class TpuAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -788,9 +823,9 @@ class TpuAsyncClient:
 
             from google.cloud import tpu_v1
 
-            def sample_start_node():
+            async def sample_start_node():
                 # Create a client
-                client = tpu_v1.TpuClient()
+                client = tpu_v1.TpuAsyncClient()
 
                 # Initialize request argument(s)
                 request = tpu_v1.StartNodeRequest(
@@ -801,7 +836,7 @@ class TpuAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -842,7 +877,12 @@ class TpuAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -870,9 +910,9 @@ class TpuAsyncClient:
 
             from google.cloud import tpu_v1
 
-            def sample_list_tensor_flow_versions():
+            async def sample_list_tensor_flow_versions():
                 # Create a client
-                client = tpu_v1.TpuClient()
+                client = tpu_v1.TpuAsyncClient()
 
                 # Initialize request argument(s)
                 request = tpu_v1.ListTensorFlowVersionsRequest(
@@ -883,7 +923,7 @@ class TpuAsyncClient:
                 page_result = client.list_tensor_flow_versions(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -942,12 +982,20 @@ class TpuAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListTensorFlowVersionsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -968,9 +1016,9 @@ class TpuAsyncClient:
 
             from google.cloud import tpu_v1
 
-            def sample_get_tensor_flow_version():
+            async def sample_get_tensor_flow_version():
                 # Create a client
-                client = tpu_v1.TpuClient()
+                client = tpu_v1.TpuAsyncClient()
 
                 # Initialize request argument(s)
                 request = tpu_v1.GetTensorFlowVersionRequest(
@@ -978,7 +1026,7 @@ class TpuAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_tensor_flow_version(request=request)
+                response = await client.get_tensor_flow_version(request=request)
 
                 # Handle the response
                 print(response)
@@ -1036,7 +1084,12 @@ class TpuAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1056,9 +1109,9 @@ class TpuAsyncClient:
 
             from google.cloud import tpu_v1
 
-            def sample_list_accelerator_types():
+            async def sample_list_accelerator_types():
                 # Create a client
-                client = tpu_v1.TpuClient()
+                client = tpu_v1.TpuAsyncClient()
 
                 # Initialize request argument(s)
                 request = tpu_v1.ListAcceleratorTypesRequest(
@@ -1069,7 +1122,7 @@ class TpuAsyncClient:
                 page_result = client.list_accelerator_types(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -1128,12 +1181,20 @@ class TpuAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListAcceleratorTypesAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1154,9 +1215,9 @@ class TpuAsyncClient:
 
             from google.cloud import tpu_v1
 
-            def sample_get_accelerator_type():
+            async def sample_get_accelerator_type():
                 # Create a client
-                client = tpu_v1.TpuClient()
+                client = tpu_v1.TpuAsyncClient()
 
                 # Initialize request argument(s)
                 request = tpu_v1.GetAcceleratorTypeRequest(
@@ -1164,7 +1225,7 @@ class TpuAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_accelerator_type(request=request)
+                response = await client.get_accelerator_type(request=request)
 
                 # Handle the response
                 print(response)
@@ -1222,7 +1283,12 @@ class TpuAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1236,7 +1302,9 @@ class TpuAsyncClient:
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-tpu",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-tpu",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
